# Klasse, die Drucker-spezifische Inhalte für den Seriendruck mit Methoden zur Verfügung stellt
# Für alle Ultimaker 2, 3 und 3 Extended

class PrinterInfo():
    def __init__(self) -> None:
        # speichert den Namen vom aktuell eingestellten Drucker
        self._printername = ""
        # speichert den 1. Paragraphen vom aktuellen gcode
        self._firstparagraph = None
        self._xcoordinate = "0"


# Setter ---------------------------------------------------------------------------------------------------------------
    # aktualisiert den Druckernamen
    def setPrinterName(self, machinename):
        self._printername = machinename

    # aktualisiert den ersten Paragraphen, sodass er vom aktuellen gcode ist
    def setFirstParagraph(self, firstparagraph):
        self._firstparagraph = firstparagraph

    # aktualisiert die x-oder z-Koordinate
    def setxcoordinate(self, var_x):
        self._xcoordinate = str(var_x)

# Funktionen -----------------------------------------------------------------------------------------------------------
    # Gibt die maximale für den Druckkopf erreichbare y-Koordinate zurück
    # Quellen: Handbücher von Ultimaker zu den einzelnen Druckern
    def findbacky(self):
        # Druckabmessungen: 120 x 120 mm
        if "Ultimaker 2 Go" in self._printername:
            return "120"
        # Alle weiteren Ultimaker 2 haben gleiche Länge und Breite von 223 x 223 mm
        elif "Ultimaker 2" in self._printername:
            return "223"
        # 230 x 190 mm
        elif "Ultimaker S3" in self._printername:
            return "190"
        # 215 x 215 mm
        elif "Ultimaker 3" in self._printername:
            return "215"
        # 330 x 240 mm
        elif "Ultimaker S5" in self._printername:
            return "240"
        else:
            return "0"

    def findpushx(self):
        x = self._xcoordinate
        if "." in x:
            indexdot = x.find(".")
            x = x[0:indexdot+5]
        x = float(x)
        # Druckabmessungen: 120 x 120 x 115 mm
        if "Ultimaker 2 Go" in self._printername:
            return str((120/2)+x)
        # Alle weiteren Ultimaker 2 haben gleiche Länge und Breite von 223mm x 223mm
        elif "Ultimaker 2" in self._printername:
            return str((223/2)+x)
        elif "Ultimaker S3" in self._printername:
            return str((230/2)+x)
        elif "Ultimaker 3" in self._printername:
            return str((215/2)+x)
        elif "Ultimaker S5" in self._printername:
            return str((330/2)+x)
        else:
            return "0"

    # Gibt die minimale für den Druckkopf erreichbare y-Koordinate zurück
    # Um diese auszulesen, haben wir den Nullpunkt der Ultimaker Drucker
    # mittels Gcode-samples ermittelt: vordere linke Ecke
    def findpushy(self):
        if "Ultimaker" in self._printername:
            return "0"
        else:
            return "0"

    # gibt die Hälfte der max. z-Ausrichtung zurück
    def findpushz(self):
        maxz = "0"
        textarray = self._firstparagraph.split(";")
        for element in textarray:
            if "Ultimaker 2" in self._printername:
                if "MAXZ" in element:
                    maxz = element.split(":")[1]
                else:
                    continue
            elif "Ultimaker 3" in self._printername:
                if "MAX.Z" in element:
                    maxz = element.split("MAX.Z:")[-1]
            elif "Ultimaker S3" in self._printername:
                if "MAX.Z" in element:
                    maxz = element.split("MAX.Z:")[-1]
            elif "Ultimaker S5" in self._printername:
                if "MAXZ" in element:
                    maxz = element.split("MAXZ:")[-1]
                else:
                    continue
            else:
                continue
        return float(maxz) / 2

    # gibt gcode-Befehle zum Warten und Abkühlen zurück
    # Ultimaker 2: Warte nach dem Druck, bis sich die Platte abgekühlt hat, denn sonst könnte sich das Objekt verziehen
    # Quelle: https://www.youtube.com/watch?v=5dYIYaItr1w 8:24

    def waitncool(self):
        # Warte 5 min
        if "Ultimaker 2 Go" in self._printername:
            return "G4 S300\n"
        elif "Ultimaker 2" in self._printername:
            return "G4 S300\n"
        elif "Ultimaker 3" in self._printername:
            #Kühle das Heizbett auf 0 runter und warte dabei
            return "G4 S120\n"
        else:
            return ";"

    # gibt gcode-Befehle zur minimalen Geschwindigkeit des Extruders wieder
    def slowestspeed(self):
        # für 2,3,5: 30 mm/s, sind 1800 mm/m
        return " F1800\n"
