// Import der QtQuick Elemente
import QtQuick 2.2
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.3

// Import der Uranium GUI Elemente
import UM 1.1 as UM
import Cura 1.0 as Cura

// Dialog von Uranium
UM.Dialog
{
    //Name
    id: base

    //Schriftzug im Balken
    title: "Sarlex_Serializer"

    //Wenn Dialog offen, kein Input ins Cura-Hauptfenster
    modality: Qt.ApplicationModal

    //Groesse des Fensters
    width: 815
    height: 615

//-----------------------------------------------------------------------------------------------
    // Definition der Property Variablen
    property int fuelldichte: manager.fuelldichte
    property string stueckzahl: manager.stueckzahl
    property int qualitaet: manager.qualitaet
    property string infillmethod : ""
    property string objektName: manager.objektName
    property var printMaterialLengths: PrintInformation.materialLengths
    property var printMaterialWeights: PrintInformation.materialWeights
    property string machinename : Cura.MachineManager.activeMachine.id
    property int fertigclicked : manager.fertigclicked

//-----------------------------------------------------------------------------------------------

//Das Image bildet die unterste Schicht der GUI
//Sorgt für die optische Aufwertung wie z.B. das Dreieck hinter dem Slider
 Image {
        //Name
        id: image

        //Groesse und Position
        x: 0
        y: 0
        width: 800
        height: 600

        //Informationen zur Quelldatei
        sourceSize.height: 600
        sourceSize.width: 800
        fillMode: Image.Stretch
        source: "./Serializer_Main_Image.jpeg"

//Alle weiteren Elemente sind ueber das Image gelegt

//--------------LABELS---------------------------------------------------------------------------------------------------------------
        Label {
            //Name
            id: labelAusgObj

            //Groesse und Position
            x: 147
            y: 16
            width: 192
            height: 30

            //Eigenschaften
            text: qsTr("Ausgewähltes Objekt:")
            font.underline: false
            font.bold: true
            font.pointSize: 13
        }

        Label {
            //Name
            id: labelObjektname

            //Groesse und Position
            x: 343
            y: 16
            width: 320
            height: 30

            //Eigenschaften
            text: objektName
            font.pointSize: 13
        }

   Label {
            //Name
            id: labelFilament

            //Groesse und Position
            x: 147
            y: 409
            width: 157
            height: 23

            //Eigenschaften
            text: (textfeld_verwendeteRollen.text > 0) ? qsTr("Filament (in Rollen):") : qsTr("Filament (in Rollen): Drücken Sie bitte Slice.")
            font.pointSize: 13
        }
        
        Label {
            //Name
            id: labelInfillMethode

            //Groesse und Position
            x: 537
            y: 316
            width: 126
            height: 30

            //Eigenschaften
            text: qsTr("Infill-Methode")
            font.bold: true
            font.underline: true
            font.pointSize: 13
        }

        Label {
            //Name
            id: labelInfillStaerke

            //Groesse und Position
            x: 147
            y: 316
            width: 106
            height: 30

            //Eigenschaften
            text: qsTr("Infill-Stärke")
            font.bold: true
            font.underline: true
            font.pointSize: 13
        }

        Label {
            //Name
            id: labelQualitaet

            //Groesse und Position
            x: 147
            y: 472
            width: 66
            height: 30

            //Eigenschaften
            text: qsTr("Qualität")
            font.pointSize: 13
        }

        Label {
            //Name
            id: labelAnzahl

            //Groesse und Position
            x: 485
            y: 409
            width: 83
            height: 23

            //Eigenschaften
            text: qsTr("Stückzahl:")
            font.pointSize: 13
        }

    

//---------------ICON IMAGES---------------------------------------------------------------------------------------------------------------------

        Image {
                id: imSquare
                x: 654
                y: 185
                width: 60
                height: 60
                sourceSize.height: 60
                sourceSize.width: 60
                fillMode: Image.Stretch
                source: "./SquareIcon.png"
        }

        Image {
                id: imZigzag
                x: 572
                y: 246
                width: 60
                height: 60
                sourceSize.height: 60
                sourceSize.width: 60
                fillMode: Image.Stretch
                source: "./ZigzagIcon.png"
        }

        Image {
                id: imHexagon
                x: 485
                y: 188
                width: 60
                height: 60
                sourceSize.height: 60
                sourceSize.width: 60
                fillMode: Image.Stretch
                source: "./HexIcon.png"
        }

        Image {
                id: imTriangle
                x: 618
                y: 84
                width: 60
                height: 60
                sourceSize.height: 60
                sourceSize.width: 60
                fillMode: Image.Stretch
                source: "./TriIcon.png"
        }

        Image {
                id: imGrid
                x: 514
                y: 87
                width: 60
                height: 60
                sourceSize.height: 60
                sourceSize.width: 60
                fillMode: Image.Stretch
                source: "./GridIcon.png"
        }


//---------------BUTTONS-------------------------------------------------------------------------------------------------------------------------------

  //nur einer darf gedrückt werden (exklusiv)--------------------------------------------------------------
        ExclusiveGroup {id: infillButtons}


            Button {
                //Viereck
                exclusiveGroup: infillButtons

                //Groesse und Position
                x: 654
                y: 185
                width: 60
                height: 60

                //Eigenschaften
                checkable: true
                opacity: (checked === true) ? 0.7 : 0.1

                //Funktionalitaet
                onClicked: {
                    manager.update_infill_methode(0)
                    infillmethod = "cubic"
                }
            }


            Button {
                //ZigZag
                exclusiveGroup: infillButtons

                //Groesse und Position
                x: 572
                y: 246
                width: 60
                height: 60

                //Eigenschaften
                checkable: true
                opacity: (checked === true) ? 0.7 : 0.1

                //Funktionalitaet
                onClicked: {
                    manager.update_infill_methode(1)
                    infillmethod = "zigzag"
                }
            }


            Button {
                //Hexagon
                exclusiveGroup: infillButtons

                //Groesse und Position
                x: 485
                y: 188
                width: 60
                height: 60

                //Eigenschaften
                checkable: true
                opacity: (checked === true) ? 0.7 : 0.1

                //Funktionalitaet
                onClicked: {
                    manager.update_infill_methode(2)
                    infillmethod = "trihexagon"
                }
            }


            Button {
                //Triangle
                exclusiveGroup: infillButtons

                //Groesse und Position
                x: 618
                y: 84
                width: 60
                height: 60

                //Eigenschaften
                checkable: true
                checked: true
                opacity: (checked === true) ? 0.7 : 0.1

                //Funktionalitaet
                onClicked: {
                    manager.update_infill_methode(3)
                    infillmethod = "triangles"
                }
            }


            Button {
                //Grid
                exclusiveGroup: infillButtons

                //Groesse und Position
                x: 514
                y: 86
                width: 60
                height: 60

                //Eigenschaften
                checkable: true
                opacity: (checked === true) ? 0.7 : 0.1

                //Funktionalitaet
                onClicked: {
                    manager.update_infill_methode(4)
                    infillmethod = "grid"
                }
            }


  //Buttons der Abschlussleiste---------------------------------------------------------------------------

        Button {
            //Name
            id: buttonBack

            //Groesse und Position
            x: 12
            y: 559
            width: 83
            height: 30

            //Eigenschaften
            text: qsTr("Zurück")


            //Funktionalitaet
            onClicked: {
              base.setVisible(false)
            }
        }

        Button {
            //Name
            id: fertigButton

            //Groesse und Position
            x: 703
            y: 559
            width: 83
            height: 30

            //Eigenschaften
            text: qsTr("Fertig")

            //Funktionalitaet
            onClicked: {
              base.setVisible(false)
              manager.update_fertig_button()
              Cura.MachineManager.setSettingForAllExtruders("infill_sparse_density", "value", fuelldichte)
              Cura.MachineManager.setSettingForAllExtruders("infill_pattern","value",infillmethod)
            }
        }

//--------------------------SLIDERS--------------------------------------------------------------------------------------------------------------------------------

        Slider {
            //Name
            id: fuelldichte_Slider

            //Groesse und Position
            x: 175
            y: 84
            width: 50
            height: 222

            //Eigenschaften
            value: fuelldichte
            minimumValue: 0
            stepSize: 1
            maximumValue: 100
            orientation: Qt.Vertical

            //Funktionalitaet
            activeFocusOnPress: true
            onValueChanged: {
                // nur die Änderung des Sliders wird registriert, nicht z.B. die Änderung des Textfelds
                // nur der Slider ist aktiv, die anderen Objekte passiv -> keine Kettenreaktion bei Verrechnung der Werte
                if(fuelldichte_Slider.activeFocus === true) {
                    manager.update_fuelldichte(fuelldichte_Slider.value)
                }
            }
        }

        Slider {
            //Name
            id: qualitaetSlider

            //Groesse und Position
            x: 230
            y: 472
            width: 433
            height: 30

            //Eigenschaften
            value: qualitaet
            minimumValue: 0
            stepSize: 1
            maximumValue: 100
            orientation: Qt.Horizontal

            //Funktionalitaet
            activeFocusOnPress: true
            onValueChanged: {
              if (qualitaetSlider.activeFocus === true) {
                  manager.update_qualitaet(qualitaetSlider.value)
              }
            }
        }

//--------------TEXTFIELDS--------------------------------------------------------------------------------------------------------------------------------------------------
        TextField {
            id: textfeld_stueckzahl
            x: 564
            y: 406
            width: 70
            height: 30
            placeholderText: qsTr("1 bis 100")
            style: UM.Theme.styles.text_field;

            text: stueckzahl 
            onTextChanged: {
                if (textfeld_stueckzahl.activeFocus === true) {
                    manager.update_stueckzahl(textfeld_stueckzahl.text)
                    Cura.MachineManager.setSettingForAllExtruders("infill_sparse_density", "value", 0)
                    Cura.MachineManager.setSettingForAllExtruders("infill_sparse_density", "value", fuelldichte)
                }
            }
        }


        TextField {
            id: textfeld_verwendeteRollen
            x: 306
            y: 406
            width: 70
            height: 30
            placeholderText: qsTr("1 bis 100")
            style: UM.Theme.styles.text_field;
            readOnly: true
            visible:(textfeld_verwendeteRollen.text > 0) ? true : false
            
            text:
                {                    var totalWeights = 0
                    var totalLengths = 0
                    if (printMaterialLengths)
                    {
                        for(var index = 0; index < printMaterialLengths.length; index++)
                        {
                            if(printMaterialLengths[index] > 0)
                            {
                                totalLengths += printMaterialLengths[index]
                                totalWeights += Math.round(printMaterialWeights[index])
                            }
                        }
                    }
                    return (totalWeights*parseFloat(stueckzahl)/750).toFixed(2)

                }
            font.pointSize: 13
           
        }

//--------------TEXTFIELDS, NUR UM WERTE ZU ÜBERGEBEN---------------------------------------------------------------------------------------------------------------

        TextField {
            id: machinenameworkaround
            x: 10
            y: 10
            width: 70
            height: 30

            visible:false

            text: machinename
            onTextChanged: {
                manager.updatemachine(machinename)
            }
        }

        TextField {
            id: xcoordinateworkaround
            x: 100
            y: 11
            width: 70
            height: 30

            visible:false

            text: UM.ActiveTool.properties.getValue("X")
            onTextChanged: {
                manager.updatex(xcoordinateworkaround.text)
            }
        }

 } //ENDE - IMAGE

//--------------Notification--------------------------------------------------------------------------------------------------------------------------------------------------

  Item
    {
        objectName: "SerializerStuekzahlButton"
        visible: stueckzahl > 0 && fertigclicked > 0
        height: UM.Theme.getSize("action_button").height
        width: height

        Cura.SecondaryButton
        {
            height: UM.Theme.getSize("action_button").height
            onClicked: base.show()
            iconSource: "StueckzahlNotification.svg"
            fixedWidthMode: false
        }

        Cura.NotificationIcon
        {
            id: stuekzahlCountIcon
            visible: stueckzahl > 0
            anchors
            {
                top: parent.top
                right: parent.right
                rightMargin: (-0.5 * width) | 0
                topMargin: (-0.5 * height) | 0
            }

            labelText: stueckzahl
        }
    }

} //ENDE - UM DIALOG




